@@ -1,6 +1,6 @@
 """REST client handling, including GoogleAdsStream base class."""
 
-import requests
+from urllib.parse import urlencode, urljoin
 from pathlib import Path
 from typing import Any, Dict, Optional, Union, List, Iterable
 
@@ -9,6 +9,7 @@ from memoization import cached
 from singer_sdk.helpers.jsonpath import extract_jsonpath
 from singer_sdk.streams import RESTStream
 from singer_sdk.exceptions import FatalAPIError, RetriableAPIError
+from singer_sdk.pagination import JSONPathPaginator
 
 from tap_googleads.auth import GoogleAdsAuthenticator
 from tap_googleads.utils import replicate_pk_at_root
@@ -20,10 +21,10 @@ SCHEMAS_DIR = Path(__file__).parent / Path("./schemas")
 class GoogleAdsStream(RESTStream):
     """GoogleAds stream class."""
 
-    url_base = "https://googleads.googleapis.com/v12"
+    url_base = "https://googleads.googleapis.com/v14"
 
     records_jsonpath = "$[*]"  # Or override `parse_response`.
-    next_page_token_jsonpath = "$.nextPageToken"  # Or override `get_next_page_token`.
+    next_page_token_jsonpath = "$.nextPageToken"
     primary_keys_jsonpaths = None
     _LOG_REQUEST_METRIC_URLS: bool = True
 
@@ -32,11 +33,13 @@ class GoogleAdsStream(RESTStream):
     def authenticator(self) -> GoogleAdsAuthenticator:
         """Return a new authenticator object."""
         base_auth_url = "https://www.googleapis.com/oauth2/v4/token"
-        # Silly way to do parameters but it works
-        auth_url = base_auth_url + f"?refresh_token={self.config['refresh_token']}"
-        auth_url = auth_url + f"&client_id={self.config['client_id']}"
-        auth_url = auth_url + f"&client_secret={self.config['client_secret']}"
-        auth_url = auth_url + f"&grant_type=refresh_token"
+        auth_params = {
+            "refresh_token": self.config["refresh_token"],
+            "client_id": self.config["client_id"],
+            "client_secret": self.config["client_secret"],
+            "grant_type": "refresh_token",
+        }
+        auth_url = urljoin(base_auth_url, "?" + urlencode(auth_params))
         return GoogleAdsAuthenticator(stream=self, auth_endpoint=auth_url)
 
     @property
@@ -49,23 +52,8 @@ class GoogleAdsStream(RESTStream):
         headers["login-customer-id"] = self.config["login_customer_id"]
         return headers
 
-    def get_next_page_token(
-        self, response: requests.Response, previous_token: Optional[Any]
-    ) -> Optional[Any]:
-        """Return a token for identifying next page or None if no more pages."""
-        # TODO: If pagination is required, return a token which can be used to get the
-        #       next page. If this is the final page, return "None" to end the
-        #       pagination loop.
-        if self.next_page_token_jsonpath:
-            all_matches = extract_jsonpath(
-                self.next_page_token_jsonpath, response.json()
-            )
-            first_match = next(iter(all_matches), None)
-            next_page_token = first_match
-        else:
-            next_page_token = None
-
-        return next_page_token
+    def get_new_paginator(self) -> JSONPathPaginator:
+        return JSONPathPaginator(self.next_page_token_jsonpath)
 
     def get_url_params(
         self, context: Optional[dict], next_page_token: Optional[Any]
@@ -145,21 +133,6 @@ class GoogleAdsStream(RESTStream):
                 f"disabled after the API that lists customers is called.  {e=}"
             )
 
-    def prepare_request_payload(
-        self, context: Optional[dict], next_page_token: Optional[Any]
-    ) -> Optional[dict]:
-        """Prepare the data payload for the REST API request.
-
-        By default, no payload will be sent (return None).
-        """
-        # TODO: Delete this method if no payload is required. (Most REST APIs.)
-        return None
-
-    def parse_response(self, response: requests.Response) -> Iterable[dict]:
-        """Parse the response and return an iterator of result rows."""
-        # TODO: Parse response body and return a set of records.
-        yield from extract_jsonpath(self.records_jsonpath, input=response.json())
-
     def post_process(self, row: dict, context: Optional[dict] = None) -> Optional[dict]:
         """As needed, append or transform raw data to match expected structure."""
         return replicate_pk_at_root(row, self.primary_keys_jsonpaths)
